@@ -77,6 +77,9 @@ FAILEDOPERATION_GETTASKLISTFAILED = 'FailedOperation.GetTaskListFailed'
 # 获取媒资信息失败。
 FAILEDOPERATION_GETVIDEOMETADATAFAILED = 'FailedOperation.GetVideoMetadataFailed'
 
+# 图片数量过多。
+FAILEDOPERATION_IMAGENUMEXCEEDED = 'FailedOperation.ImageNumExceeded'
+
 # MD5不匹配。
 FAILEDOPERATION_MD5MISMATCH = 'FailedOperation.MD5Mismatch'
 
@@ -104,6 +107,9 @@ FAILEDOPERATION_PERSONDUPLICATED = 'FailedOperation.PersonDuplicated'
 # 人脸图片不属于已知人物。
 FAILEDOPERATION_PERSONNOTMATCHED = 'FailedOperation.PersonNotMatched'
 
+# 自定义人物数量过多。
+FAILEDOPERATION_PERSONNUMEXCEEDED = 'FailedOperation.PersonNumExceeded'
+
 # 图片质量分检测失败。
 FAILEDOPERATION_QUALITYALGOFAILED = 'FailedOperation.QualityAlgoFailed'
 
@@ -194,7 +200,7 @@ INVALIDPARAMETER_INVALIDPAGENUMBER = 'InvalidParameter.InvalidPageNumber'
 # 分页大小不合法。
 INVALIDPARAMETER_INVALIDPAGESIZE = 'InvalidParameter.InvalidPageSize'
 
-# 输入字段不合法。
+# 输入字段 %!s(MISSING) 不合法。
 INVALIDPARAMETER_INVALIDPARAM = 'InvalidParameter.InvalidParam'
 
 # 人物ID不合法。
